==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cloudngfw/kotlin/inputs/GetPreRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cloudngfw.kotlin.inputs

import com.pulumi.azurenative.cloudngfw.inputs.GetPreRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property globalRulestackName GlobalRulestack resource name
 * @property priority Pre Rule priority
 */
public data class GetPreRulePlainArgs(
    public val globalRulestackName: String,
    public val priority: String,
) : ConvertibleToJava<com.pulumi.azurenative.cloudngfw.inputs.GetPreRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cloudngfw.inputs.GetPreRulePlainArgs =
        com.pulumi.azurenative.cloudngfw.inputs.GetPreRulePlainArgs.builder()
            .globalRulestackName(globalRulestackName.let({ args0 -> args0 }))
            .priority(priority.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPreRulePlainArgs].
 */
@PulumiTagMarker
public class GetPreRulePlainArgsBuilder internal constructor() {
    private var globalRulestackName: String? = null

    private var priority: String? = null

    /**
     * @param value GlobalRulestack resource name
     */
    @JvmName("klehumtsnsnuhwry")
    public suspend fun globalRulestackName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.globalRulestackName = mapped
    }

    /**
     * @param value Pre Rule priority
     */
    @JvmName("shgiqbcubxvllmst")
    public suspend fun priority(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.priority = mapped
    }

    internal fun build(): GetPreRulePlainArgs = GetPreRulePlainArgs(
        globalRulestackName = globalRulestackName ?: throw PulumiNullFieldException("globalRulestackName"),
        priority = priority ?: throw PulumiNullFieldException("priority"),
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/cloudngfw/kotlin/inputs/GetPreRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cloudngfw.kotlin.inputs

import com.pulumi.azurenative.cloudngfw.inputs.GetPreRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property globalRulestackName GlobalRulestack resource name
 * @property priority Pre Rule priority
 */
public data class GetPreRulePlainArgs(
    public val globalRulestackName: String,
    public val priority: String,
) : ConvertibleToJava<com.pulumi.azurenative.cloudngfw.inputs.GetPreRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cloudngfw.inputs.GetPreRulePlainArgs =
        com.pulumi.azurenative.cloudngfw.inputs.GetPreRulePlainArgs.builder()
            .globalRulestackName(globalRulestackName.let({ args0 -> args0 }))
            .priority(priority.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPreRulePlainArgs].
 */
@PulumiTagMarker
public class GetPreRulePlainArgsBuilder internal constructor() {
    private var globalRulestackName: String? = null

    private var priority: String? = null

    /**
     * @param value GlobalRulestack resource name
     */
    @JvmName("tjrqlrjbvqyhykqm")
    public suspend fun globalRulestackName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.globalRulestackName = mapped
    }

    /**
     * @param value Pre Rule priority
     */
    @JvmName("vuagxslpjijwfjld")
    public suspend fun priority(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.priority = mapped
    }

    internal fun build(): GetPreRulePlainArgs = GetPreRulePlainArgs(
        globalRulestackName = globalRulestackName ?: throw PulumiNullFieldException("globalRulestackName"),
        priority = priority ?: throw PulumiNullFieldException("priority"),
    )
}
